@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c,v 1.6.2.2 2006/05/31 07:13:46 pborelli Exp $
+ * $Id: gedit-commands-file.c,v 1.10 2006/05/31 15:40:12 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -67,8 +67,8 @@ static void tab_state_changed_while_saving (GeditTab    *tab,
 					    GeditWindow *window);
 
 void
-gedit_cmd_file_new (GtkAction   *action,
-		    GeditWindow *window)
+_gedit_cmd_file_new (GtkAction   *action,
+		     GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -190,27 +190,60 @@ load_file_list (GeditWindow         *window,
 	return loaded_files;
 }
 
-/* Exported so it can be used for drag'n'drop */
-gint
-gedit_cmd_load_files (GeditWindow         *window,
-		      const GSList        *uris,
-		      const GeditEncoding *encoding)
+/**
+ * gedit_commands_load_uri:
+ *
+ * Do nothing if URI does not exist
+ */
+void
+gedit_commands_load_uri (GeditWindow         *window,
+			 const gchar         *uri,
+			 const GeditEncoding *encoding,
+			 gint                 line_pos)
 {
-	gedit_debug (DEBUG_COMMANDS);
+	GSList *uris = NULL;
+	
+	g_return_if_fail (GEDIT_IS_WINDOW (window));
+	g_return_if_fail (uri != NULL);
 
-	return load_file_list (window, uris, encoding, 0, FALSE);
+	gedit_debug (DEBUG_COMMANDS);	
+	
+	uris = g_slist_prepend (uris, (gchar *)uri);
+	
+	load_file_list (window, uris, encoding, line_pos, FALSE);
+	
+	g_slist_free (uris);	
+}
+
+/**
+ * gedit_commands_load_uri:
+ *
+ * Ignore non-existing URIs 
+ */
+gint
+gedit_commands_load_uris (GeditWindow         *window,
+			  const GSList        *uris,
+			  const GeditEncoding *encoding,
+			  gint                 line_pos)
+{	
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
+	g_return_val_if_fail ((uris != NULL) && (uris->data != NULL), 0);
+	
+	gedit_debug (DEBUG_COMMANDS);
+	
+	return load_file_list (window, uris, encoding, line_pos, FALSE);
 }
 
 /*
  * From the command line we can specify a line position for the
- * first doc. Beside specifying a not existing uri crates a
+ * first doc. Beside specifying a not existing uri creates a
  * titled document.
  */
 gint
-gedit_cmd_load_files_from_prompt (GeditWindow         *window,
-				  const GSList        *uris,
-				  const GeditEncoding *encoding,
-				  gint                 line_pos)
+_gedit_cmd_load_files_from_prompt (GeditWindow         *window,
+				   const GSList        *uris,
+				   const GeditEncoding *encoding,
+				   gint                 line_pos)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -253,17 +286,18 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
-	gedit_cmd_load_files (window,
-			      uris,
-			      encoding);
+	gedit_commands_load_uris (window,
+				  uris,
+				  encoding,
+				  0);
 
 	g_slist_foreach (uris, (GFunc) g_free, NULL);
 	g_slist_free (uris);
 }
 
 void
-gedit_cmd_file_open (GtkAction   *action,
-		     GeditWindow *window)
+_gedit_cmd_file_open (GtkAction   *action,
+		      GeditWindow *window)
 {
 	GtkWidget     *open_dialog;
 	gpointer       data;
@@ -415,17 +449,18 @@ open_location_dialog_response_cb (GeditOpenLocationDialog *dlg,
 
 	gtk_widget_destroy (GTK_WIDGET (dlg));
 
-	gedit_cmd_load_files (window,
-		 	      uris,
-			      encoding);
+	gedit_commands_load_uris (window,
+				  uris,
+				  encoding,
+				  0);
 
 	g_slist_foreach (uris, (GFunc) g_free, NULL);
 	g_slist_free (uris);
 }
 
 void
-gedit_cmd_file_open_uri (GtkAction   *action,
-			 GeditWindow *window)
+_gedit_cmd_file_open_uri (GtkAction   *action,
+			  GeditWindow *window)
 {
 	GtkWidget *dlg;
 	gpointer   data;
@@ -462,8 +497,8 @@ gedit_cmd_file_open_uri (GtkAction   *action,
 }
 
 void
-gedit_cmd_file_open_recent (EggRecentItem *item,
-			    GeditWindow   *window)
+_gedit_cmd_file_open_recent (EggRecentItem *item,
+			     GeditWindow   *window)
 {
 	GSList *uris = NULL;
 	gchar  *uri;
@@ -474,7 +509,7 @@ gedit_cmd_file_open_recent (EggRecentItem *item,
 
 	uris = g_slist_prepend (uris, uri);
 
-	if (gedit_cmd_load_files (window, uris, NULL) != 1)
+	if (gedit_commands_load_uris (window, uris, NULL, 0) != 1)
 		gedit_recent_remove (uri);
 
 	g_slist_foreach (uris, (GFunc) g_free, NULL);
@@ -821,7 +856,7 @@ file_save (GeditTab    *tab,
 }
 
 void
-gedit_cmd_file_save (GtkAction   *action,
+_gedit_cmd_file_save (GtkAction   *action,
 		     GeditWindow *window)
 {
 	GeditTab *tab;
@@ -836,7 +871,7 @@ gedit_cmd_file_save (GtkAction   *action,
 }
 
 void
-gedit_cmd_file_save_as (GtkAction   *action,
+_gedit_cmd_file_save_as (GtkAction   *action,
 			GeditWindow *window)
 {
 	GeditTab *tab;
@@ -962,7 +997,7 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 }
 
 void
-gedit_cmd_file_save_all (GtkAction   *action,
+_gedit_cmd_file_save_all (GtkAction   *action,
 			 GeditWindow *window)
 {
 	GList *docs;
@@ -1136,7 +1171,7 @@ revert_dialog (GeditWindow   *window,
 }
 
 void
-gedit_cmd_file_revert (GtkAction   *action,
+_gedit_cmd_file_revert (GtkAction   *action,
 		       GeditWindow *window)
 {
 	GeditDocument  *doc;
@@ -1613,7 +1648,7 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 }
 
 void
-gedit_cmd_file_close (GtkAction   *action,
+_gedit_cmd_file_close (GtkAction   *action,
 		      GeditWindow *window)
 {
 	GeditTab *active_tab;
@@ -1699,7 +1734,7 @@ file_close_all (GeditWindow *window,
 }
 
 void
-gedit_cmd_file_close_all (GtkAction   *action,
+_gedit_cmd_file_close_all (GtkAction   *action,
 			  GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
@@ -1714,7 +1749,7 @@ gedit_cmd_file_close_all (GtkAction   *action,
 
 /* Quit */
 void
-gedit_cmd_file_quit (GtkAction   *action,
+_gedit_cmd_file_quit (GtkAction   *action,
 		     GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
