@@ -21,7 +21,7 @@ import os
 import gtk
 from gtk import gdk
 import gnomevfs
-import gedit
+import gedit, gtksourceview
 from gettext import gettext as _
 from outputpanel import OutputPanel
 from capture import *
@@ -65,7 +65,7 @@ class ToolsTree:
 		return None
 	
 	def save(self):
-		self.tree.write(self.xml_location)
+		self.tree.write(self.xml_location, 'UTF-8')
 		
 	def get_tool_from_accelerator(self, keyval, mod, ignore = None):
 		if not self.root:
@@ -74,7 +74,7 @@ class ToolsTree:
 		for tool in self.root:
 			if tool != ignore:
 				skey, smod = gtk.accelerator_parse(default(tool.get('accelerator'), ''))
-				if skey == keyval and smod & mod == smod:
+				if skey == keyval and mod == smod:
 					return tool
 		return None
 
@@ -137,7 +137,7 @@ def remove_tools_menu(window):
 	window.set_data("ToolsPluginCommandsData", None)
 
 def update_tools_menu(tools = None):
-	for window in gedit.gedit_app_get_default().get_windows():
+	for window in gedit.app_get_default().get_windows():
 		remove_tools_menu(window)
 		insert_tools_menu(window, tools)
 		filter_tools_menu(window)
@@ -200,9 +200,9 @@ def capture_menu_action(action, window, node):
 				capture.set_env(GEDIT_CURRENT_DOCUMENT_PATH = path,
 				                GEDIT_CURRENT_DOCUMENT_DIR  = cwd)
 		
-		documents_uri = [document.get_uri()
-		                         for document in window.get_documents()
-		                         if document.get_uri() is not None]
+		documents_uri = [doc.get_uri()
+		                         for doc in window.get_documents()
+		                         if doc.get_uri() is not None]
 		documents_path = [gnomevfs.get_local_path_from_uri(uri)
 		                         for uri in documents_uri
 		                         if gnomevfs.get_uri_scheme(uri) == 'file']
@@ -229,15 +229,15 @@ def capture_menu_action(action, window, node):
 				if output_type == 'replace-selection':
 					document.select_range(start, end)
 		elif input_type == 'line':
-			start = document.get_insert()
-			end = insert.copy()
+			start = document.get_iter_at_mark(document.get_insert())
+			end = start.copy()
 			if not start.starts_line():
 				start.backward_line()
 			if not end.ends_line():
 				end.forward_to_line_end()
 		elif input_type == 'word':
-			start = document.get_insert()
-			end = insert.copy()
+			start = document.get_iter_at_mark(document.get_insert())
+			end = start.copy()
 			if not start.inside_word():
 				panel.write(_('You must be inside a word to run this command'),
 				            panel.command_tag)
@@ -282,7 +282,8 @@ def capture_menu_action(action, window, node):
 
 	capture.connect('stderr-line',   capture_stderr_line_panel,   panel)
 	capture.connect('begin-execute', capture_begin_execute_panel, panel, node.get('label'))
-	capture.connect('end-execute',   capture_end_execute_panel,   panel, view)
+	capture.connect('end-execute',   capture_end_execute_panel,   panel, view, 
+	                output_type in ('new-document','replace-document'))
 	
 	# Run the command
 	view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(gdk.Cursor(gdk.WATCH))
@@ -298,8 +299,21 @@ def capture_begin_execute_panel(capture, panel, label):
 	panel.write(_("Running tool:"), panel.italic_tag);
 	panel.write(" %s\n\n" % label, panel.bold_tag);
 
-def capture_end_execute_panel(capture, exit_code, panel, view):
+def capture_end_execute_panel(capture, exit_code, panel, view, update_type):
 	panel['stop'].set_sensitive(False)
+	
+	if update_type:
+		doc = view.get_buffer()
+		start = doc.get_start_iter()
+		end = start.copy()
+		end.forward_chars(300)
+		
+		mtype = gnomevfs.get_mime_type_for_data(doc.get_text(start, end))
+		languages_manager = gtksourceview.SourceLanguagesManager()
+		language = languages_manager.get_language_from_mime_type(mtype)
+		if language is not None:
+			doc.set_language(language)
+	
 	view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(gdk.Cursor(gdk.XTERM))
 	view.set_cursor_visible(True)
 	view.set_editable(True)
